Test For Sample User Functions
open | ../tests/html/test_type_page1.html |
typeRepeated | username | Test
verifyValue | username | TestTest
verifyValueRepeated | username | Test
verifyElementPresent | valuerepeated=Test |
verifyElementNotPresent | valuerepeated=X |
typeRepeated | valuerepeated=Test | X
verifyElementPresent | valuerepeated=X |
storeTextLength | //h3 | myVar
verifyTextLength | //h3 | regexp:4[1-5]
waitForTextLength | //h3 | ${myVar}
verifyNotTextLength | //h3 | 46